==> ejc-sale-impl-3.0.0-20220605.112218-140-sources.jar: com/ejianc/business/sale/vo/InvoiceVO.java <==
package com.ejianc.business.sale.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.sale.bean.ReceivablesinvoiceEntity;
import com.ejianc.business.sale.bean.ReceivablessummaryEntity;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.sale.vo.InvoicedetialVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 发票管理
 * 
 * @author generator
 * 
 */
public class InvoiceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long customerId; // 客户主键
    private String customerName; // 客户名称
    private Long profitcenterId; // 利润中心id
    private String profitcenterName; // 利润中心名称
    private BigDecimal invoiceMoney; // 发票金额
    private BigDecimal balanceMoney; // 发票余额金额
    private Long receivablesType; // 收款类型id
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkoutTime; // 结账年月日
    private Integer invoicesStatus; // 发票状态
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String abstracts; // 摘要
    private Integer isSale; // 是否关联销售单
    private BigDecimal stayDistributionMoney; // 已开待分配金额
    
    private List<InvoicedetialVO> invoicedetialList = new ArrayList<>(); // 发票管理子表
    private List<ReceivablessummaryVO> receivablessummaryList = new ArrayList<>(); // 付款汇总管理子表
    private List<ReceivablesinvoiceVO> receivablesinvoicelist = new ArrayList<>(); // 付款开票子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="CustomermanageRef")
    public Long getCustomerId() {
        return customerId;
    }

    @ReferDeserialTransfer
    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    @ReferSerialTransfer(referCode="ProfitcenterRef")
    public Long getProfitcenterId() {
        return profitcenterId;
    }

    @ReferDeserialTransfer
    public void setProfitcenterId(Long profitcenterId) {
        this.profitcenterId = profitcenterId;
    }
    public String getProfitcenterName() {
        return profitcenterName;
    }

    public void setProfitcenterName(String profitcenterName) {
        this.profitcenterName = profitcenterName;
    }
    public BigDecimal getInvoiceMoney() {
        return invoiceMoney;
    }

    public void setInvoiceMoney(BigDecimal invoiceMoney) {
        this.invoiceMoney = invoiceMoney;
    }
    public BigDecimal getBalanceMoney() {
        return balanceMoney;
    }

    public void setBalanceMoney(BigDecimal balanceMoney) {
        this.balanceMoney = balanceMoney;
    }
    public Long getReceivablesType() {
        return receivablesType;
    }

    public void setReceivablesType(Long receivablesType) {
        this.receivablesType = receivablesType;
    }
    public Date getCheckoutTime() {
        return checkoutTime;
    }

    public void setCheckoutTime(Date checkoutTime) {
        this.checkoutTime = checkoutTime;
    }
    public Integer getInvoicesStatus() {
        return invoicesStatus;
    }

    public void setInvoicesStatus(Integer invoicesStatus) {
        this.invoicesStatus = invoicesStatus;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getAbstracts() {
        return abstracts;
    }

    public void setAbstracts(String abstracts) {
        this.abstracts = abstracts;
    }
    
     public List<InvoicedetialVO> getInvoicedetialList() {
        return invoicedetialList;
     }

     public void setInvoicedetialList(List<InvoicedetialVO> invoicedetialList) {
        this.invoicedetialList = invoicedetialList;
     }

    public List<ReceivablessummaryVO> getReceivablessummaryList() {
        return receivablessummaryList;
    }

    public void setReceivablessummaryList(List<ReceivablessummaryVO> receivablessummaryList) {
        this.receivablessummaryList = receivablessummaryList;
    }

    public List<ReceivablesinvoiceVO> getReceivablesinvoicelist() {
        return receivablesinvoicelist;
    }

    public void setReceivablesinvoicelist(List<ReceivablesinvoiceVO> receivablesinvoicelist) {
        this.receivablesinvoicelist = receivablesinvoicelist;
    }

    public Integer getIsSale() {
        return isSale;
    }

    public void setIsSale(Integer isSale) {
        this.isSale = isSale;
    }

    public BigDecimal getStayDistributionMoney() {
        return stayDistributionMoney;
    }

    public void setStayDistributionMoney(BigDecimal stayDistributionMoney) {
        this.stayDistributionMoney = stayDistributionMoney;
    }
}

==> ejc-sale-impl-3.0.0-20220628.070817-175-sources.jar: com/ejianc/business/sale/vo/InvoiceVO.java <==
package com.ejianc.business.sale.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.business.sale.bean.ReceivablesinvoiceEntity;
import com.ejianc.business.sale.bean.ReceivablessummaryEntity;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.sale.vo.InvoicedetialVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 发票管理
 * 
 * @author generator
 * 
 */
public class InvoiceVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编号
    private Long customerId; // 客户主键
    private String customerName; // 客户名称
    private Long profitcenterId; // 利润中心id
    private String profitcenterName; // 利润中心名称
    private BigDecimal invoiceMoney; // 发票金额
    private BigDecimal balanceMoney; // 发票余额金额
    private Long receivablesType; // 收款类型id
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date checkoutTime; // 结账年月日
    private Integer invoicesStatus; // 发票状态
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称
    private String abstracts; // 摘要
    private Integer isSale; // 是否关联销售单
    private BigDecimal stayDistributionMoney; // 已开待分配金额
    
    private List<InvoicedetialVO> invoicedetialList = new ArrayList<>(); // 发票管理子表
    private List<ReceivablessummaryVO> receivablessummaryList = new ArrayList<>(); // 付款汇总管理子表
    private List<ReceivablesinvoiceVO> receivablesinvoicelist = new ArrayList<>(); // 付款开票子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    @ReferSerialTransfer(referCode="CustomermanageRef")
    public Long getCustomerId() {
        return customerId;
    }

    @ReferDeserialTransfer
    public void setCustomerId(Long customerId) {
        this.customerId = customerId;
    }
    public String getCustomerName() {
        return customerName;
    }

    public void setCustomerName(String customerName) {
        this.customerName = customerName;
    }
    @ReferSerialTransfer(referCode="idm-user")
    public Long getProfitcenterId() {
        return profitcenterId;
    }

    @ReferDeserialTransfer
    public void setProfitcenterId(Long profitcenterId) {
        this.profitcenterId = profitcenterId;
    }
    public String getProfitcenterName() {
        return profitcenterName;
    }

    public void setProfitcenterName(String profitcenterName) {
        this.profitcenterName = profitcenterName;
    }
    public BigDecimal getInvoiceMoney() {
        return invoiceMoney;
    }

    public void setInvoiceMoney(BigDecimal invoiceMoney) {
        this.invoiceMoney = invoiceMoney;
    }
    public BigDecimal getBalanceMoney() {
        return balanceMoney;
    }

    public void setBalanceMoney(BigDecimal balanceMoney) {
        this.balanceMoney = balanceMoney;
    }
    public Long getReceivablesType() {
        return receivablesType;
    }

    public void setReceivablesType(Long receivablesType) {
        this.receivablesType = receivablesType;
    }
    public Date getCheckoutTime() {
        return checkoutTime;
    }

    public void setCheckoutTime(Date checkoutTime) {
        this.checkoutTime = checkoutTime;
    }
    public Integer getInvoicesStatus() {
        return invoicesStatus;
    }

    public void setInvoicesStatus(Integer invoicesStatus) {
        this.invoicesStatus = invoicesStatus;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getAbstracts() {
        return abstracts;
    }

    public void setAbstracts(String abstracts) {
        this.abstracts = abstracts;
    }
    
     public List<InvoicedetialVO> getInvoicedetialList() {
        return invoicedetialList;
     }

     public void setInvoicedetialList(List<InvoicedetialVO> invoicedetialList) {
        this.invoicedetialList = invoicedetialList;
     }

    public List<ReceivablessummaryVO> getReceivablessummaryList() {
        return receivablessummaryList;
    }

    public void setReceivablessummaryList(List<ReceivablessummaryVO> receivablessummaryList) {
        this.receivablessummaryList = receivablessummaryList;
    }

    public List<ReceivablesinvoiceVO> getReceivablesinvoicelist() {
        return receivablesinvoicelist;
    }

    public void setReceivablesinvoicelist(List<ReceivablesinvoiceVO> receivablesinvoicelist) {
        this.receivablesinvoicelist = receivablesinvoicelist;
    }

    public Integer getIsSale() {
        return isSale;
    }

    public void setIsSale(Integer isSale) {
        this.isSale = isSale;
    }

    public BigDecimal getStayDistributionMoney() {
        return stayDistributionMoney;
    }

    public void setStayDistributionMoney(BigDecimal stayDistributionMoney) {
        this.stayDistributionMoney = stayDistributionMoney;
    }
}
